Frequenz Microgrid API
======================

Microgrid is a gRPC API used to provide monitoring and control over the
components of a microgrid.

This repository provides the core gRPC and protobuf spec together with
support for generating dedicated API packages for various languages.


Contributing
============

If you want to know how to build this project and contribute to it, please
check out the [Contributing
Guide](https://github.com/frequenz-floss/frequenz-api-microgrid/CONTRIBUTING.md).
